SystemOrganization addCategory: #ConfigurationOfNagare!

Object subclass: #ConfigurationOfNagare
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfNagare'!

!ConfigurationOfNagare class methodsFor: 'private' stamp: 'mu 5/3/2012 15:00'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfNagare class methodsFor: 'catalog' stamp: 'MasashiUmezawa 6/26/2016 11:57'!
catalogDescription

^ 
'nagare-logger
=============

Nagare is a new flexible logger which connects to fluentd (http://fluentd.org).

* Simple log interfaces with reliable backend
* Semi-structured logging (Not only String, you can store structured records in log)
* Portable (runs on VW, Squeak, and Pharo)

For more info, please see the github project page (https://github.com/mumez/nagare-logger).

'! !

!ConfigurationOfNagare class methodsFor: 'catalog' stamp: 'MasashiUmezawa 6/26/2016 12:05'!
catalogKeyClassesAndExample
	^ '[Setting up Nagare]

Set the host parameter to point to the fluentd host (default is ''localhost'')
[[[
NgSettings default host: ''<hostname>''.
]]]
Set the log level you would like to use (default is 5).
[[[
NgSettings default logLevel: 5.
]]]

For other setting parameters, please see NgSettings class.

[Hello log world]

[[[
NgLog default info: ''Hello World!!''.
NgLog default warn: ''Nagare!!''.
]]]

In st.YYYYMMDD\_N.log file, you can see the entry like:
[[[
2012-05-13T17:00:58+09:00 st.info "Hello World!!"
2012-05-13T17:00:59+09:00 st.warn "Nagare!!"
]]]
If you prefer, you can write more shortly:

self ng info: ''Hello Nagare!!''.'

! !

!ConfigurationOfNagare class methodsFor: 'catalog' stamp: 'MasashiUmezawa 6/26/2016 11:59'!
catalogKeywords
	^ #(logger log logging fluentd messagepack)! !

!ConfigurationOfNagare class methodsFor: 'development support' stamp: 'mu 5/3/2012 15:00'!
compareVersions
	"Compare previous version to development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfNagare class methodsFor: 'development support' stamp: 'mu 5/3/2012 15:00'!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfNagare class methodsFor: 'private' stamp: 'mu 5/3/2012 15:00'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfNagare class methodsFor: 'metacello tool support' stamp: 'mu 5/3/2012 15:00'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfNagare class methodsFor: 'metacello tool support' stamp: 'mu 5/3/2012 15:00'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfNagare class methodsFor: 'loading' stamp: 'mu 5/3/2012 15:00'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfNagare class methodsFor: 'metacello tool support' stamp: 'mu 5/3/2012 15:00'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfNagare class methodsFor: 'accessing' stamp: 'mu 5/3/2012 15:00'!
project

	^self new project! !

!ConfigurationOfNagare class methodsFor: 'development support' stamp: 'mu 5/3/2012 15:00'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- fixed a bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfNagare class methodsFor: 'development support' stamp: 'MasashiUmezawa 6/12/2016 14:49'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfNagare methodsFor: 'baselines' stamp: 'mu 5/3/2012 21:56'!
baseline100: spec 
	<version: '1.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			repository: 'http://ss3.gemstone.com/ss/Nagare'.
		spec
			project: 'MessagePack Core' with: [
				spec
					className: 'ConfigurationOfMessagePack'; loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec
			project: 'StOMP Core' with: [
				spec
					className: 'ConfigurationOfStOMP'; loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Nagare-Core' with: [ spec requires: 'MessagePack Core' ].
		spec 
			package: 'NagareTest-Core' with: [ spec requires: #('Nagare-Core' 'StOMP Core') ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Nagare-Core');
			group: 'Tests' with: #('NagareTest-Core'). ].
	
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Core' with: [ spec includes: #('Nagare-Squeak-Core') ]. 
		spec
			group: 'Core' with: #('Nagare-Squeak-Core')]
	! !

!ConfigurationOfNagare methodsFor: 'baselines' stamp: 'mu 6/26/2017 18:32'!
baseline110: spec 
	<version: '1.1-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			repository: 'http://ss3.gemstone.com/ss/Nagare'.
		spec
			project: 'MessagePack Core' with: [
				spec
					className: 'ConfigurationOfMessagePack'; loads: #('Core' );
					repository: 'http://smalltalkhub.com/mc/MasashiUmezawa/MessagePack/main' ].
		spec
			project: 'MessagePack Test' with: [
				spec
					className: 'ConfigurationOfMessagePack'; loads: #('Tests' );
					repository: 'http://smalltalkhub.com/mc/MasashiUmezawa/MessagePack/main' ].
		spec
			project: 'StOMP Core' with: [
				spec
					className: 'ConfigurationOfStOMP'; loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Nagare-Core' with: [ spec requires: 'MessagePack Core' ].
		spec 
			package: 'NagareTest-Core' with: [ spec requires: #('Nagare-Core' 'StOMP Core') ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Nagare-Core');
			group: 'Tests' with: #('NagareTest-Core'). ].
	
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Core' with: [ spec includes: #('Nagare-Squeak-Core') ]. 
		spec
			group: 'Core' with: #('Nagare-Squeak-Core')]
	! !

!ConfigurationOfNagare methodsFor: 'symbolic versions' stamp: 'mu 5/3/2012 15:00'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #notDefined.
! !

!ConfigurationOfNagare methodsFor: 'accessing' stamp: 'mu 5/3/2012 15:00'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		"use atomic load on GemStone to resolve some loading issues"
		Smalltalk at: #SystemVersion ifAbsent: [ project loadType: #atomic ]. 
		project ]! !

!ConfigurationOfNagare methodsFor: 'doits' stamp: 'mu 5/3/2012 15:01'!
squeakCommonPostLoadDoIt
	Smalltalk at: #NgSqPortableUtil ifPresent: [:p | p initialize]! !

!ConfigurationOfNagare methodsFor: 'symbolic versions' stamp: 'mu 6/26/2017 18:25'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'common' version: '1.1.3'! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'mu 5/4/2012 12:43'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.0.4';
			project: 'MessagePack Test' with: '1.0.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-mu.9';
			package: 'NagareTest-Core' with: 'NagareTest-Core-mu.2'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-mu.4']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'mu 5/4/2012 22:11'!
version101: spec 
	<version: '1.0.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.0.4';
			project: 'MessagePack Test' with: '1.0.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-mu.10';
			package: 'NagareTest-Core' with: 'NagareTest-Core-mu.3'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-mu.5']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'mu 5/5/2012 21:24'!
version102: spec 
	<version: '1.0.2' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.0.4';
			project: 'MessagePack Test' with: '1.0.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-mu.11';
			package: 'NagareTest-Core' with: 'NagareTest-Core-mu.3'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-mu.5']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'mu 5/13/2012 23:22'!
version103: spec 
	<version: '1.0.3' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.0.4';
			project: 'MessagePack Test' with: '1.0.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-mu.14';
			package: 'NagareTest-Core' with: 'NagareTest-Core-mu.3'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-mu.5']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'MasashiUmezawa 6/23/2014 22:02'!
version104: spec 
	<version: '1.0.4' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.0.4';
			project: 'MessagePack Test' with: '1.0.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-MasashiUmezawa.15';
			package: 'NagareTest-Core' with: 'NagareTest-Core-mu.3'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-mu.5']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'MasashiUmezawa 6/12/2016 14:51'!
version105: spec 
	<version: '1.0.5' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.0.4';
			project: 'MessagePack Test' with: '1.0.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-MasashiUmezawa.15';
			package: 'NagareTest-Core' with: 'NagareTest-Core-mu.3'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-MasashiUmezawa.6']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'MasashiUmezawa 6/12/2016 14:50'!
version110: spec 
	<version: '1.1.0' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.2.3';
			project: 'MessagePack Test' with: '1.2.3'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-MasashiUmezawa.16';
			package: 'NagareTest-Core' with: 'NagareTest-Core-MasashiUmezawa.4'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-MasashiUmezawa.7']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'MasashiUmezawa 6/26/2016 11:52'!
version111: spec 
	<version: '1.1.1' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.2.3';
			project: 'MessagePack Test' with: '1.2.3'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-MasashiUmezawa.16';
			package: 'NagareTest-Core' with: 'NagareTest-Core-MasashiUmezawa.4'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-MasashiUmezawa.8']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'MasashiUmezawa 12/29/2016 15:20'!
version112: spec 
	<version: '1.1.2' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #stable.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.2.4';
			project: 'MessagePack Test' with: '1.2.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-MasashiUmezawa.17';
			package: 'NagareTest-Core' with: 'NagareTest-Core-MasashiUmezawa.4'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-MasashiUmezawa.8']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'mu 6/26/2017 18:25'!
version113: spec 
	<version: '1.1.3' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #stable.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.2.5';
			project: 'MessagePack Test' with: '1.2.5'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-MasashiUmezawa.17';
			package: 'NagareTest-Core' with: 'NagareTest-Core-MasashiUmezawa.4'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-MasashiUmezawa.8']! !
